@@ -20,6 +20,8 @@
 #define VIEW_H
 
 #include <QtQuick/QQuickView>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
 #include "dialog.h"
 
@@ -53,7 +55,9 @@ public:
     void setFreeFloating(bool floating);
 
     QStringList history() const;
+
     Q_INVOKABLE void addToHistory(const QString &item);
+    Q_INVOKABLE void removeFromHistory(int index);
 
 Q_SIGNALS:
     void historyChanged();
@@ -80,7 +84,9 @@ protected Q_SLOTS:
     void slotFocusWindowChanged();
 
 private:
+    void writeHistory();
     void initWayland();
+
     QPoint m_customPos;
     KDeclarative::QmlObject *m_qmlObj;
     KConfigGroup m_config;
